Module container

Module container 

Provides an abstraction over MSF and MSFZ files.

Enums

Container
An abstraction over MSF and MSFZ files. Both types of files contain a set of streams.
StreamReader
Allows reading a stream using the Read, Seek, and ReadAt traits.