DbiSourcesSubstream

Struct DbiSourcesSubstream 

pub struct DbiSourcesSubstream<'a> { /* private fields */ }
The “Sources” substream of the DBI stream. This stream describes the merged set of source files that were the inputs (compilands) of all modules.

See: https://llvm.org/docs/PDB/DbiStream.html#file-info-substream

Implementations

Source

impl<'a> DbiSourcesSubstream<'a>

pub fn num_modules(&self) -> usize

The number of modules

pub fn file_name_offsets(&self) -> &'a [U32<LE>]

Provides access to the file name offsets slice. Each value is a file name offset, and can be used with get_source_name_at().

pub fn parse(substream_data: &'a [u8]) -> Result<Self>

Parses the file info substream.

This does not parse or validate every part of the substream. It only parses enough to find the module indices and file names.

pub fn get_source_file_name( &self, source_file_index: usize, ) -> Result<&'a BStr, ParserError>

Given a source file index, returns the source file name.

pub fn get_source_file_name_at( &self, file_name_offset: u32, ) -> Result<&'a BStr, ParserError>

Given a file name offset (within name_buffer), returns the source file name.

pub fn name_offsets_for_module(&self, module_index: usize) -> Result<&[U32<LE>]>

Caller is expected to validate module_index (against num_modules()) before calling

pub fn iter_sources(&self) -> IterSources<'_>

Iterates source files in the DBI Sources Substream.

pub fn sources_map(&self) -> Result<HashMap<u32, &BStr>>

Builds a HashMap that maps from file name offsets to strings.