pub struct DbiStream<StreamData = Vec<u8>>{
pub stream_data: StreamData,
pub substreams: DbiSubstreamRanges,
}Expand description
Holds or refers to the DBI stream.
The StreamData type parameter can be any type that can contain [u8].
This type contains (or refers to) the entire DBI stream, not just the header.
Fields
stream_data: StreamDataThe contents of the stream.
substreams: DbiSubstreamRangesThe byte ranges of the substreams.
Implementations
Sourceimpl<StreamData: AsRef<[u8]>> DbiStream<StreamData>
impl<StreamData: AsRef<[u8]>> DbiStream<StreamData>
Sourcepub fn modules_bytes(&self) -> &[u8] ⓘ
pub fn modules_bytes(&self) -> &[u8] ⓘ
The unparsed contents of the modules_bytes substream.
Sourcepub fn modules_bytes_mut(&mut self) -> &mut [u8] ⓘ
pub fn modules_bytes_mut(&mut self) -> &mut [u8] ⓘ
The unparsed contents of the modules_bytes substream.
Sourcepub fn section_contributions_bytes(&self) -> &[u8] ⓘ
pub fn section_contributions_bytes(&self) -> &[u8] ⓘ
The unparsed contents of the section_contributions_bytes substream.
Sourcepub fn section_contributions_bytes_mut(&mut self) -> &mut [u8] ⓘ
pub fn section_contributions_bytes_mut(&mut self) -> &mut [u8] ⓘ
The unparsed contents of the section_contributions_bytes substream.
Sourcepub fn section_map_bytes(&self) -> &[u8] ⓘ
pub fn section_map_bytes(&self) -> &[u8] ⓘ
The unparsed contents of the section_map_bytes substream.
Sourcepub fn section_map_bytes_mut(&mut self) -> &mut [u8] ⓘ
pub fn section_map_bytes_mut(&mut self) -> &mut [u8] ⓘ
The unparsed contents of the section_map_bytes substream.
Sourcepub fn source_info(&self) -> &[u8] ⓘ
pub fn source_info(&self) -> &[u8] ⓘ
The unparsed contents of the source_info substream.
Sourcepub fn source_info_mut(&mut self) -> &mut [u8] ⓘ
pub fn source_info_mut(&mut self) -> &mut [u8] ⓘ
The unparsed contents of the source_info substream.
Sourcepub fn type_server_map(&self) -> &[u8] ⓘ
pub fn type_server_map(&self) -> &[u8] ⓘ
The unparsed contents of the type_server_map substream.
Sourcepub fn type_server_map_mut(&mut self) -> &mut [u8] ⓘ
pub fn type_server_map_mut(&mut self) -> &mut [u8] ⓘ
The unparsed contents of the type_server_map substream.
Sourcepub fn edit_and_continue(&self) -> &[u8] ⓘ
pub fn edit_and_continue(&self) -> &[u8] ⓘ
The unparsed contents of the edit_and_continue substream.
Sourcepub fn edit_and_continue_mut(&mut self) -> &mut [u8] ⓘ
pub fn edit_and_continue_mut(&mut self) -> &mut [u8] ⓘ
The unparsed contents of the edit_and_continue substream.
Sourcepub fn optional_debug_header_bytes(&self) -> &[u8] ⓘ
pub fn optional_debug_header_bytes(&self) -> &[u8] ⓘ
The unparsed contents of the optional_debug_header_bytes substream.
Sourceimpl<StreamData: AsRef<[u8]>> DbiStream<StreamData>
impl<StreamData: AsRef<[u8]>> DbiStream<StreamData>
Sourcepub fn header(&self) -> Result<&DbiStreamHeader>
pub fn header(&self) -> Result<&DbiStreamHeader>
Returns the DBI stream header.
Sourcepub fn header_mut(&mut self) -> Result<&mut DbiStreamHeader>
pub fn header_mut(&mut self) -> Result<&mut DbiStreamHeader>
Provides mutable access to the DBI stream header.
Sourcepub fn modules(&self) -> ModInfoSubstream<&[u8]>
pub fn modules(&self) -> ModInfoSubstream<&[u8]>
Reads the Module Information substream.
Sourcepub fn iter_modules(&self) -> IterModuleInfo<'_> ⓘ
pub fn iter_modules(&self) -> IterModuleInfo<'_> ⓘ
Iterates the Module records in the Module Information Substream.
Sourcepub fn iter_modules_mut(&mut self) -> IterModuleInfoMut<'_> ⓘ
pub fn iter_modules_mut(&mut self) -> IterModuleInfoMut<'_> ⓘ
Iterates the Module records in the Module Information Substream, with mutable access.
Sourcepub fn parse(stream_data: StreamData) -> Result<Self>
pub fn parse(stream_data: StreamData) -> Result<Self>
Read the DBI Stream header and validate it.
Sourcepub fn sources(&self) -> Result<DbiSourcesSubstream<'_>>
pub fn sources(&self) -> Result<DbiSourcesSubstream<'_>>
Parses the DBI Sources Substream section.
Sourcepub fn section_contributions(&self) -> Result<SectionContributionsSubstream<'_>>
pub fn section_contributions(&self) -> Result<SectionContributionsSubstream<'_>>
Parses the header of the Section Contributions Substream and returns an object which can query it.
Sourcepub fn section_map(&self) -> Result<SectionMap<'_>>
pub fn section_map(&self) -> Result<SectionMap<'_>>
Parses the header of the Section Map Substream and returns an object which can query it.
Sourcepub fn optional_debug_header(&self) -> Result<OptionalDebugHeader<'_>>
pub fn optional_debug_header(&self) -> Result<OptionalDebugHeader<'_>>
Parses the Optional Debug Header Substream and returns an object which can query it.