#[repr(C)]pub struct DbiStreamHeader {Show 20 fields
pub signature: I32<LE>,
pub version: U32<LE>,
pub age: U32<LE>,
pub global_symbol_index_stream: StreamIndexU16,
pub build_number: U16<LE>,
pub public_symbol_index_stream: StreamIndexU16,
pub pdb_dll_version: U16<LE>,
pub global_symbol_stream: StreamIndexU16,
pub pdb_dll_rbld: U16<LE>,
pub mod_info_size: I32<LE>,
pub section_contribution_size: I32<LE>,
pub section_map_size: I32<LE>,
pub source_info_size: I32<LE>,
pub type_server_map_size: I32<LE>,
pub mfc_type_server_index: U32<LE>,
pub optional_dbg_header_size: I32<LE>,
pub edit_and_continue_size: I32<LE>,
pub flags: U16<LE>,
pub machine: U16<LE>,
pub padding: U32<LE>,
}Expand description
The header of the DBI (Debug Information) stream.
Fields
signature: I32<LE>Always -1
version: U32<LE>One of the DBI_STREAM_VERSION_* values; typically, DBI_STREAM_VERSION_V110.
age: U32<LE>The number of times this PDB has been modified. The value is set to 1 when a PDB is first created. This value must match the same field within the PE header.
global_symbol_index_stream: StreamIndexU16The index of the Global Symbol Index, which contains a name-to-symbol lookup table for global symbols. The symbol records are not stored in this stream; they are stored in the Global Symbol Stream.
build_number: U16<LE>public_symbol_index_stream: StreamIndexU16The index of the stream that contains the Public Symbol Index (GSI). This contains a
name-to-symbol map and an address-to-symbol map. See crate::globals::gsi.
pdb_dll_version: U16<LE>The version of the MSPDB DLL which produced this DBI stream.
global_symbol_stream: StreamIndexU16The stream that contains the Global Symbol Stream. This contains symbol records, which can
be decoded using crate::syms::SymIter.
pdb_dll_rbld: U16<LE>mod_info_size: I32<LE>section_contribution_size: I32<LE>section_map_size: I32<LE>source_info_size: I32<LE>type_server_map_size: I32<LE>mfc_type_server_index: U32<LE>This field is not a substream size. Not sure what it is.
optional_dbg_header_size: I32<LE>edit_and_continue_size: I32<LE>flags: U16<LE>machine: U16<LE>padding: U32<LE>Implementations
Sourceimpl DbiStreamHeader
impl DbiStreamHeader
Sourcepub fn sym_record_stream(&self) -> Result<u32, StreamIndexIsNilError>
pub fn sym_record_stream(&self) -> Result<u32, StreamIndexIsNilError>
Gets the stream index for the Global Symbol Stream.
Sourcepub fn public_stream_index(&self) -> Result<u32, StreamIndexIsNilError>
pub fn public_stream_index(&self) -> Result<u32, StreamIndexIsNilError>
Gets the stream index for the Public Symbol Index.
Sourcepub fn global_stream_index(&self) -> Result<u32, StreamIndexIsNilError>
pub fn global_stream_index(&self) -> Result<u32, StreamIndexIsNilError>
Gets the stream index for the Global Symbol Index.
Sourcepub fn modules_range(&self) -> Result<Range<usize>>
pub fn modules_range(&self) -> Result<Range<usize>>
Byte range of the Modules substream.
Sourcepub fn sources_range(&self) -> Result<Range<usize>>
pub fn sources_range(&self) -> Result<Range<usize>>
Byte range of the Modules substream.
Sourcepub fn total_substreams_len(&self) -> Option<u32>
pub fn total_substreams_len(&self) -> Option<u32>
The total length of all substreams, or None if this value cannot be computed.
In a well-formed DBI stream, this value can be computed and the value is less than the size of the data that follows the DBI Stream Header.