NameTable

Struct NameTable 

pub struct NameTable { /* private fields */ }
Contains a Name Table, as used in the GSI and PSI.

Implementations

Source

impl NameTable

pub fn parse( num_buckets: usize, stream_offset: usize, sym_hash_bytes: &[u8], ) -> Result<Self>

Parses a NameTable. For the GSI, the entire GSI stream contains only a NameTable. For the PSI, the PSI stream begins with a PsiStreamHeader, followed by a NameTable`.

pub fn empty() -> Self

Constructs an empty instance

pub fn check_hashes(&self, global_symbols: &GlobalSymbolStream) -> Result<()>

Check all of the hash records in the name table and verify that the hash of the name for this record matches the hash bucket that the hash record is in.

pub fn hash_records_for_bucket(&self, bucket: usize) -> &[HashRecord]

Gets the hash records for a specific bucket index. The caller is responsible for using a valid bucket index.

pub fn hash_records_for_name<'a>(&'a self, name: &BStr) -> &'a [HashRecord]

Gets the hash records that might contain name.

pub fn find_symbol<'a>( &self, gss: &'a GlobalSymbolStream, name: &BStr, ) -> Result<Option<Sym<'a>>>

Searches for name in the Name Table. The caller must provide access to the GSS.

pub fn iter<'i, 'a: 'i>( &'a self, gss: &'a GlobalSymbolStream, ) -> NameTableIter<'i>

Iterates the names stored within a NameTable.