#[repr(C)]pub struct NameTableHeader {
pub signature: U32<LE>,
pub version: U32<LE>,
pub hash_records_size: U32<LE>,
pub buckets_size: U32<LE>,
}Expand description
This header is present at the start of the Name Table.
Immediately after this header follows the hash records, whose length is given by
cb_hash_records. This section contains an array of HashRecord structs.
Immediately after the hash records is the hash buckets, whose length is given by cb_buckets.
Called GSIHashHdr in C++.
Fields
signature: U32<LE>Constant which identifies this as a NameTableHeader. This value (0xffff_ffff) was chosen
because the previous version of the NameTable did not use this header, and this
signature value would never have occurred in the same position in the previous version.
version: U32<LE>Version of the name hash table.
hash_records_size: U32<LE>Size in bytes of the hash records. This should always be a multiple of
size_of::<HashRecord>(), not HASH_RECORD_CALC_LEN.
buckets_size: U32<LE>Size in bytes of the hash buckets.