Module hash

Module hash 

MSVC hash algorithms

Functions

hash_mod_u16
Computes a 16-bit hash
hash_mod_u32
Computes a 32-bit hash. This produces the same results as the hash function used in the MSVC PDB reader library.
hash_sig
Computes a hash code using an algorithm equivalent to the SigForPbCb function. This is a CRC-32 checksum with an initial value of sig.
hash_sig_mod
Computes a CRC-32 with an initializer value, then computes the modulus of it.
hash_u32
Computes a 32-bit hash, but does not compute a remainder (modulus).