Module lines

Module lines 

Decodes line information found in Module Streams.

References

Structs

Block
One block of line data. Each block has a header which points to a source file. All of the line locations within the block point to line numbers (and potentially column numbers) within that source file.
BlockHeader
Header for a variable-length Block record.
BlockMut
One block of line data. Each block has a header which points to a source file. All of the line locations within the block point to line numbers (and potentially column numbers) within that source file.
ChecksumKind
The hash algorithm used for the checksum.
ColumnRecord
A single column record
Contribution
FileChecksum
Points to a single file checksum record.
FileChecksumHeader
The header at the start of a file checksum record.
FileChecksumIter
Iterates FileChecksum values from a byte stream.
FileChecksumMut
Points to a single file checksum record, with mutable access.
FileChecksumMutIter
Iterator state. Iterates FileChecksumMut values.
FileChecksumsSubsection
The File Checksums Subection
FileChecksumsSubsectionMut
Like FileChecksums, but with mutable access
IterBlocks
Iterator state for LinesSubsection::blocks.
IterBlocksMut
Iterator state for LinesSubsection::blocks.
LineData
Enables decoding of the line data stored in a Module Stream. This decodes the “C13 line data” substream.
LineDataMut
Enables decoding of the line data stored in a Module Stream. This decodes the “C13 line data” substream.
LineRecord
A single line record
LinesEntry
LinesSubsection
Represents one contribution. Each contribution consists of a sequence of variable-length blocks.
LinesSubsectionMut
Represents one contribution. Each contribution consists of a sequence of variable-length blocks.
Subsection
A reference to one subsection
SubsectionHeader
The header of a subsection.
SubsectionIter
Iterator state for subsections
SubsectionIterMut
Iterator state for subsections with mutable access
SubsectionKind
Enumerates the kind of subsections found in C13 Line Data.
SubsectionMut
A reference to one subsection, with mutable access

Constants

CV_LINES_HAVE_COLUMNS
Bit flag for Contribution::flags field
JMC_LINE_FEE_FEE
This special line number is part of the “Just My Code” MSVC compiler feature.
JMC_LINE_NO_STEP_INTO
This special line number is part of the “Just My Code” MSVC compiler feature.

Functions

fixup_c13_line_data
Updates a C13 Line Data substream after NameIndex values have been updated and after file lists for a given module have been rearranged (sorted).
is_jmc_line
Returns true if line is a number that is used by the “Just My Code” MSVC compiler feature.