Struct FileChecksumHeader

#[repr(C)]
pub struct FileChecksumHeader { pub name: U32<LE>, pub checksum_size: u8, pub checksum_kind: ChecksumKind, }
The header at the start of a file checksum record.

Each file checksum record specifies the name of the file (using an offset into the Names Stream), the kind of checksum (none, SHA1, SHA256, MD5, etc.), the size of the checksum, and the checksum bytes.

The checksum record is variable-length.

Fields

name: U32<LE>

Offset into the global string table (the /names stream) of the PDB.

checksum_size: u8

The size in bytes of the checksum. The checksum bytes immediately follow the FileChecksumHeader.

checksum_kind: ChecksumKind

The hash algorithm used for the checksum.