PdbiStream

Struct PdbiStream 

pub struct PdbiStream {
    pub signature: u32,
    pub version: u32,
    pub age: u32,
    pub unique_id: Option<Uuid>,
    pub named_streams: NamedStreams,
    pub features: Vec<FeatureCode>,
}
Contains the PDB Information Stream.

This implementation reads all of the data from the PDBI Stream and converts it to in-memory data structures. This is not typical for most of the data within the PDB. We do this because the PDBI is fairly small, is needed for reading most PDBs, and will often need to be edited for generating or rebuilding PDBs.

Fields

signature: u32version: u32age: u32unique_id: Option<Uuid>named_streams: NamedStreamsfeatures: Vec<FeatureCode>

Implementations

Source

impl PdbiStream

pub fn parse(stream_data: &[u8]) -> Result<Self>

Parses the stream.

pub fn to_bytes(&self) -> Result<Vec<u8>>

Serializes this to a stream.

pub fn age(&self) -> u32

Gets the ‘age’ value of the PDB. This links the PDB with the executable; a PDB must have the same age as its related executable.

pub fn version(&self) -> u32

Version from the PDBI header, e.g. PDBI_VERSION_VC110.

pub fn binding_key(&self) -> BindingKey

The binding key that associates this PDB with a given PE executable.

pub fn named_streams(&self) -> &NamedStreams

Provides access to the named streams table.

pub fn named_streams_mut(&mut self) -> &mut NamedStreams

Provides mutable access to the named streams table.

pub fn has_feature(&self, feature_code: FeatureCode) -> bool

Checks whether this PDB has a given feature enabled.