pub struct BindingKey {
pub guid: Uuid,
pub age: u32,
}Expand description
This is the key used to associate a given PE executable (DLL or EXE) with a PDB. All values come from the PDBI stream.
Fields
guid: UuidThe GUID. When MSVC tools are run in deterministic mode, this value is a hash of the PE image, rather than being assigned using an RNG.
age: u32The age of the executable. This is incremented every time the DLL + PDB are modified.