Pdb

Struct Pdb 

pub struct Pdb<F = RandomAccessFile> { /* private fields */ }
Allows reading the contents of a PDB file.

This type provides read-only access. It does not provide any means to modify a PDB file or to create a new one.

Implementations

Source

impl<F: ReadAt> Pdb<F>

pub fn read_fixups(&self) -> Result<Option<Vec<Fixup>>>

Reads (uncached) the FIXUP_DATA optional debug stream.

Source

impl<F: ReadAt> Pdb<F>

pub fn read_dbi_stream_header(&self) -> Result<DbiStreamHeader>

Reads the header of the DBI stream. This does not validate the header.

pub fn read_dbi_stream(&self) -> Result<DbiStream<Vec<u8>>, Error>

Reads the entire DBI Stream, validates the header, and then returns an object that can be used for further queries of the DBI Stream.

pub fn read_modules(&self) -> Result<ModInfoSubstream<Vec<u8>>>

Reads the module substream data from the DBI stream.

This function always reads the data from the file. It does not cache the data.

pub fn modules(&self) -> Result<&ModInfoSubstream<Vec<u8>>>

Gets access to the DBI Modules Substream. This will read the DBI Modules Substream on-demand, and will cache it.

pub fn read_sources_data(&self) -> Result<Vec<u8>>

Reads the DBI Sources Substream. This always reads the data, and does not cache it.

pub fn sources_data(&self) -> Result<&[u8]>

Gets access to the DBI Sources Substream data.

pub fn sources(&self) -> Result<DbiSourcesSubstream<'_>>

Gets access to the DBI Sources Substream and parses the header.

pub fn drop_sources(&mut self)

Drops the cached DBI Sources Substream data, if any.

pub fn read_section_contributions(&self) -> Result<Vec<u32>>

Reads the contents of the DBI Section Contributions Substream. This function never caches the data; it is always read unconditionally.

The returned buffer is Vec<u32> instead of Vec<u8> so that natural alignment is guaranteed.

pub fn read_optional_debug_streams(&self) -> Result<OptionalDebugHeaders>

Reads (uncached) the DBI Optional Debug Streams Substream.

pub fn fixup_stream(&self) -> Result<Option<u32>>

Gets the stream index of the FIXUP_DATA optional debug stream.

pub fn optional_debug_streams(&self) -> Result<&OptionalDebugHeaders>

Gets the DBI Optional Debug Streams Substream.

pub fn optional_debug_stream( &self, i: OptionalDebugStream, ) -> Result<Option<u32>>

Gets the stream index of a specific Optional Debug Stream.

pub fn read_section_headers(&self) -> Result<Box<[IMAGE_SECTION_HEADER]>>

Reads (uncached) the contents of the “Section Headers” Optional Debug Stream.

pub fn section_headers(&self) -> Result<&[IMAGE_SECTION_HEADER]>

Gets the contents of the “Section Headers” Optional Debug Stream.

Source

impl<F: ReadAt> Pdb<F>

pub fn read_gss(&self) -> Result<GlobalSymbolStream>

Reads the Global Symbol Stream (GSS). This stream contains global symbol records.

This function does not validate the contents of the stream.

pub fn read_gsi(&self) -> Result<GlobalSymbolIndex>

Reads the Global Symbol Index (GSI). This stream contains a name-to-symbol lookup table. It indexes many global symbols, such as S_GPROCREF, S_CONSTANT, etc.

pub fn read_psi(&self) -> Result<PublicSymbolIndex>

Reads the Public Symbol Index.

Source

impl<F: ReadAt> Pdb<F>

pub fn read_module_stream( &self, mod_info: &ModuleInfo<'_>, ) -> Result<Option<ModiStreamData<StreamData>>, Error>

Reads a Module Info stream. The caller must provide a ModuleInfo structure, which comes from the DBI Stream. Use crate::dbi::read_dbi_stream to enumerate ModuleInfo values.

If the Module Info record has a NIL stream, then this function returns Ok(None).

pub fn read_module_symbols(&self, module: &ModuleInfo<'_>) -> Result<Vec<u32>>

Reads the symbol data for a specific module.

The returned buffer will contain a 4-byte header. The caller can use SymIter::for_module_syms on the returned buffer.

If the given module does not have a module stream, then this function will return Ok with a zero-length buffer, so callers should be prepared to deal with the presence or absence of the 4-byte header.

Source

impl<F: ReadAt> Pdb<F>

pub fn add_embedded_source( &mut self, file_path: &str, file_contents: &[u8], ) -> Result<bool>
where F: WriteAt,

Embeds the contents of a source file into the PDB.

pub fn add_or_replace_named_stream( &mut self, stream_name: &str, stream_contents: &[u8], ) -> Result<bool>
where F: WriteAt,

Sets the contents of a named stream to the given value.

If there is already a named stream with the given name, then the stream’s contents are replaced with stream_contents. First, though, this function reads the contents of the existing stream and compares them to stream_contents. If they are identical, then the stream is not modified and this function will return Ok(true). If the contents are not identical, then this function returns Ok(true).

If there is not already a named stream with given name, then a new stream is created and an entry is added to the Named Streams Map. In this case, the function returns Ok(false).

Source

impl<F: ReadAt> Pdb<F>

pub fn read_type_stream(&self) -> Result<TypeStream<Vec<u8>>>

Reads the TPI stream.

pub fn read_ipi_stream(&self) -> Result<TypeStream<Vec<u8>>>

Reads the IPI stream.

pub fn read_tpi_or_ipi_stream( &self, stream_index: Stream, ) -> Result<TypeStream<Vec<u8>>>

Reads the TPI or IPI stream.

Source

impl<F: ReadAt> Pdb<F>

pub fn pdbi(&self) -> &PdbiStream

Gets access to the PDB Information Stream.

This loads the PDBI on-demand. The PDBI is usually fairly small.

pub fn named_streams(&self) -> &NamedStreams

Gets access to the Named Streams table.

pub fn named_streams_mut(&mut self) -> &mut NamedStreams

Gets mutable access to the Named Streams table.

pub fn named_stream(&self, name: &str) -> Option<u32>

Searches the Named Streams table for a stream with a given name. Returns None if the stream is not found.

pub fn named_stream_err(&self, name: &str) -> Result<u32>

Searches the Named Streams table for a stream with a given name. Returns an error if the stream is not found.

pub fn dbi_header(&self) -> &DbiStreamHeader

The header of the DBI Stream.

pub fn dbi_substreams(&self) -> &DbiSubstreamRanges

The byte ranges of the DBI substreams.

pub fn tpi_header(&self) -> Result<&CachedTypeStreamHeader>

Gets the TPI Stream Header.

This loads the TPI Stream Header on-demand. This does not load the rest of the TPI Stream.

pub fn ipi_header(&self) -> Result<&CachedTypeStreamHeader>

Gets the IPI Stream Header.

This loads the IPI Stream Header on-demand. This does not load the rest of the TPI Stream.

pub fn names(&self) -> Result<&NamesStream<Vec<u8>>>

Gets the Names Stream

This loads the Names Stream on-demand.

pub fn get_name(&self, offset: NameIndex) -> Result<&BStr>

Gets a name from the Names Stream.

pub fn binding_key(&self) -> BindingKey

The binding key that associates this PDB with a given PE executable.

pub fn has_feature(&self, feature_code: FeatureCode) -> bool

Checks whether this PDB has a given feature enabled.

pub fn mini_pdb(&self) -> bool

Indicates that this PDB was built using the “Mini PDB” option, i.e. /DEBUG:FASTLINK.

pub fn gss(&self) -> Result<&GlobalSymbolStream>

Gets a reference to the Global Symbol Stream (GSS). This loads the GSS on-demand.

pub fn gss_drop(&mut self)

If the GSS has been loaded by using the gss() function, then this method frees it.

pub fn gsi(&self) -> Result<&GlobalSymbolIndex>

Gets a reference to the Global Symbol Index (GSI). This loads the GSI on-demand.

pub fn gsi_drop(&mut self)

If the GSI has been loaded by using the gsi() function, then this method frees it.

pub fn psi(&self) -> Result<&PublicSymbolIndex>

Gets a reference to the Public Symbol Index (PSI). This loads the PSI on-demand.

pub fn psi_drop(&mut self)

If the PSI has been loaded by using the psi() function, then this method frees it.

pub fn find_public_by_name(&self, name: &BStr) -> Result<Option<Pub<'_>>>

Searches for an S_PUB32 symbol by name.

pub fn find_global_by_name(&self, name: &BStr) -> Result<Option<Sym<'_>>>

Searches for a global symbol symbol by name.

This uses the Global Symbol Index (GSI). This index does not contain S_PUB32 records. Use find_public_by_name to search for S_PUB32 records.

pub fn flush_all(&mut self) -> Result<bool>
where F: WriteAt,

Writes any changes that have been buffered in memory to disk. However, this does not commit the changes. It is still necessary to call the commit() method.

The return value indicates whether any changes were written to disk. Ok(true) indicates that some change were written to disk. Ok(false) indicates that there were no buffered changes and nothing has been written to disk.

pub fn container(&self) -> &Container<F>

Gets access to the underlying container.

pub fn linker_module(&self) -> Result<ModuleInfo<'_>>

Find the "* Linker *" module, which contains the S_COFFGROUP symbols.

If the PDB does not contain a linker module then this returns Err.

pub fn linker_module_opt(&self) -> Result<Option<ModuleInfo<'_>>>

Find the "* Linker *" module, which contains the S_COFFGROUP symbols.

If the PDB does not contain a linker module then this returns Ok(None).

pub fn coff_groups(&self) -> Result<&CoffGroups>

Gets the list of COFF groups defined in this binary.

pub fn read_coff_groups(&self) -> Result<CoffGroups>

Reads (uncached) the list of COFF groups defined in this binary.

pub fn machine(&self) -> IMAGE_FILE_MACHINE

Returns the target architecture for this PE binary.

pub fn arch(&self) -> Result<Arch>

Returns the target CPU architecture.

Source

impl Pdb<RandomAccessFile>

pub fn open(file_name: &Path) -> Result<Box<Pdb<RandomAccessFile>>>

Opens a PDB file.

pub fn open_from_file(file: File) -> Result<Box<Self>>

Reads the header of a PDB file and provides access to the streams contained within the PDB file.

This function reads the MSF File Header, which is the header for the entire file. It also reads the stream directory, so it knows how to find each of the streams and the pages of the streams.

pub fn modify(filename: &Path) -> Result<Box<Pdb<RandomAccessFile>>>

Opens a PDB file for editing. The file must use the MSF container format.

pub fn modify_from_file(file: File) -> Result<Box<Self>>

Opens an existing PDB file for read/write access, given a file name.

The file must use the MSF container format. MSFZ is not supported for read/write access.

Source

impl<F: ReadAt> Pdb<F>

pub fn open_from_random_file(random_file: F) -> Result<Box<Self>>

Reads the header of a PDB file and provides access to the streams contained within the PDB file.

This function reads the MSF File Header, which is the header for the entire file. It also reads the stream directory, so it knows how to find each of the streams and the pages of the streams.

pub fn modify_from_random_file(random_file: F) -> Result<Box<Self>>

Opens an existing PDB file for read/write access, given a file name.

The file must using the MSF container format. MSFZ is not supported for read/write access.

Methods from Deref<Target = Container<F>>

pub fn msf(&self) -> Option<&Msf<F>>

Provides direct access to the MSF layer. If this PDB file is using MSFZ instead of MSF, then this function returns None.

pub fn msf_mut(&mut self) -> Option<&mut Msf<F>>

Provides direct, mutable access to the MSF layer. If this PDB file is using MSFZ instead of MSF, then this function returns None.

pub fn msf_mut_err(&mut self) -> Result<&mut Msf<F>>

Provides direct, mutable access to the MSF layer. If this PDB file is using MSFZ instead of MSF, then this function returns None.

pub fn num_streams(&self) -> u32

The total number of streams in this PDB.

Some streams may be NIL.

pub fn get_stream_reader(&self, stream: u32) -> Result<StreamReader<'_, F>>

Returns an object which can read from a given stream. The returned object implements the Read, Seek, and ReadAt traits.

pub fn read_stream_to_vec(&self, stream: u32) -> Result<Vec<u8>>

Reads an entire stream to a vector.

pub fn read_stream(&self, stream: u32) -> Result<StreamData>

Reads an entire stream to a vector.

If the stream data is stored within a single compressed chunk, then this function returns a reference to the decompressed stream data.

pub fn read_stream_to_vec_mut( &self, stream: u32, stream_data: &mut Vec<u8>, ) -> Result<()>

Reads an entire stream into an existing vector.

pub fn stream_len(&self, stream: u32) -> u64

Gets the length of a given stream, in bytes.

The stream value must be in a valid range of 0..num_streams().

If stream is a NIL stream, this function returns 0.

pub fn is_stream_valid(&self, stream: u32) -> bool

Returns true if stream is a valid stream index and is not a nil stream.