pub struct RandomAccessFile(/* private fields */);Expand description
A file with cross-platform positioned I/O.
Reading from this file or writing to it does not use its internal OS cursor,
but it may move it anyway. This can cause surprising behaviour if shared
with a File (this could be done with try_clone).
Implementations
Sourceimpl RandomAccessFile
impl RandomAccessFile
Sourcepub fn open<P>(path: P) -> Result<RandomAccessFile, Error>
pub fn open<P>(path: P) -> Result<RandomAccessFile, Error>
Attempts to open a file in read-only mode.
See File::open for details.
Sourcepub fn create<P>(path: P) -> Result<RandomAccessFile, Error>
pub fn create<P>(path: P) -> Result<RandomAccessFile, Error>
Opens a file in write-only mode.
See File::create for details.
Sourcepub fn sync_all(&self) -> Result<(), Error>
pub fn sync_all(&self) -> Result<(), Error>
Attempts to sync all OS-internal metadata to disk.
See File::sync_all for details.
Sourcepub fn sync_data(&self) -> Result<(), Error>
pub fn sync_data(&self) -> Result<(), Error>
This function is similar to sync_all, except that it may not
synchronize file metadata to the filesystem.
See File::sync_data for details.
Sourcepub fn set_len(&self, size: u64) -> Result<(), Error>
pub fn set_len(&self, size: u64) -> Result<(), Error>
Truncates or extends the underlying file, updating the size of this file
to become size.
See File::set_len for details.
Sourcepub fn metadata(&self) -> Result<Metadata, Error>
pub fn metadata(&self) -> Result<Metadata, Error>
Queries metadata about the underlying file.
See File::metadata for details.
Sourcepub fn try_clone(&self) -> Result<RandomAccessFile, Error>
pub fn try_clone(&self) -> Result<RandomAccessFile, Error>
Creates a new File instance that shares the same underlying file handle
as the existing File instance
See File::try_clone for details.
Sourcepub fn set_permissions(&self, perm: Permissions) -> Result<(), Error>
pub fn set_permissions(&self, perm: Permissions) -> Result<(), Error>
Changes the permissions on the underlying file.
See File::set_permissions for details.
Sourcepub fn into_inner(self) -> File
pub fn into_inner(self) -> File
Unwraps the inner File.
The file’s cursor position is unspecified.