#[repr(transparent)]pub struct StreamIndexU16(pub U16<LE>);Expand description
This structure can be embedded directly in structure definitions.
Tuple Fields
0: U16<LE>Implementations
Sourceimpl StreamIndexU16
impl StreamIndexU16
Sourcepub fn get(self) -> Option<u32>
pub fn get(self) -> Option<u32>
Checks whether this value is a nil stream index. Returns Ok if the value is not a nil
stream index, or Err if it is a nil stream index.
Sourcepub fn get_err(self) -> Result<u32, StreamIndexIsNilError>
pub fn get_err(self) -> Result<u32, StreamIndexIsNilError>
Checks whether this value is a nil stream index. Returns Ok if the value is not a nil
stream index, or Err if it is a nil stream index.