#[repr(C)]pub struct ArmSwitchTable {
pub offset_base: U32<LittleEndian>,
pub sect_base: U16<LittleEndian>,
pub switch_type: U16<LittleEndian>,
pub offset_branch: U32<LittleEndian>,
pub offset_table: U32<LittleEndian>,
pub sect_branch: U16<LittleEndian>,
pub sect_table: U16<LittleEndian>,
pub num_entries: U32<LittleEndian>,
}Expand description
Data for S_ARMSWITCHTABLE.
This describes a switch table (jump table).
MSVC generates this symbol only when targeting ARM64. LLVM generates this symbol for all target architectures.
Fields
offset_base: U32<LittleEndian>Section-relative offset to the base for switch offsets
sect_base: U16<LittleEndian>Section index of the base for switch offsets
switch_type: U16<LittleEndian>type of each entry
offset_branch: U32<LittleEndian>Section-relative offset to the table branch instruction
offset_table: U32<LittleEndian>Section-relative offset to the start of the table
sect_branch: U16<LittleEndian>Section index of the table branch instruction
sect_table: U16<LittleEndian>Section index of the table
num_entries: U32<LittleEndian>number of switch table entries
Implementations
Sourceimpl ArmSwitchTable
impl ArmSwitchTable
Sourcepub fn base(&self) -> OffsetSegment
pub fn base(&self) -> OffsetSegment
The [segment:offset] of the jump base.
This is the base address of the target of the jump. The value stored within the jump table entry is added to this base.
LLVM often generates tables where base and table have the same address, but this is
not necessarily true for all tables.
Sourcepub fn branch(&self) -> OffsetSegment
pub fn branch(&self) -> OffsetSegment
The [segment:offset] of the branch instruction.
Sourcepub fn table(&self) -> OffsetSegment
pub fn table(&self) -> OffsetSegment
The [segment:offset] of the jump table.
Sourcepub fn switch_type(&self) -> ArmSwitchType
pub fn switch_type(&self) -> ArmSwitchType
The type of switch table (2-byte, 4-byte, etc.).
Sourcepub fn num_entries(&self) -> u32
pub fn num_entries(&self) -> u32
The number of entries in the jump table.