#[repr(C)]pub struct LVarAddrGap {
pub gap_start_offset: U16<LittleEndian>,
pub range_size: U16<LittleEndian>,
}Expand description
Represents the holes in overall address range, all address is pre-bbt. it is for compress and reduce the amount of relocations need.
See CV_LVAR_ADDR_GAP
Fields
gap_start_offset: U16<LittleEndian>relative offset from the beginning of the live range.
range_size: U16<LittleEndian>length of this gap, in bytes