#[repr(C)]pub struct OffsetSegment {
pub offset: U32<LittleEndian>,
pub segment: U16<LittleEndian>,
}Expand description
Stores an offset and segment pair, in that order. This structure is directly embedded in
on-disk structures.
Fields
offset: U32<LittleEndian>The offset in bytes of a symbol within a segment.
segment: U16<LittleEndian>The segment (section) index.
Implementations
Sourceimpl OffsetSegment
impl OffsetSegment