ProcFixed

Struct ProcFixed 

#[repr(C)]
pub struct ProcFixed { pub p_parent: U32<LittleEndian>, pub p_end: U32<LittleEndian>, pub p_next: U32<LittleEndian>, pub proc_len: U32<LittleEndian>, pub debug_start: U32<LittleEndian>, pub debug_end: U32<LittleEndian>, pub proc_type: TypeIndexLe, pub offset_segment: OffsetSegment, pub flags: u8, }
Used for the header of procedure symbols. This is used for S_LPROC32, S_GPROC32, S_LPROC32_ID, etc.

See PROCSYM32 in cvinfo.h.

Fields

p_parent: U32<LittleEndian>

This field is always zero; procedure symbols never have parents.

p_end: U32<LittleEndian>

The byte offset, relative to the start of this procedure record, of the S_END symbol that closes the scope of this symbol record.

p_next: U32<LittleEndian>proc_len: U32<LittleEndian>

The length in bytes of the procedure instruction stream.

debug_start: U32<LittleEndian>

The offset in bytes from the start of the procedure to the point where the stack frame has been set up. Parameter and frame variables can be viewed at this point.

debug_end: U32<LittleEndian>

The offset in bytes from the start of the procedure to the point where the procedure is ready to return and has calculated its return value, if any. Frame and register variables can still be viewed.

proc_type: TypeIndexLe

This field is either a TypeIndex that points into the TPI or is an ItemId that points into the IPI.

This field is a TypeIndex for the following symbols: S_GPROC32, S_LPROC32, S_LPROC32EX, S_LPROC32_DPC, S_GPROC32EX.

This field is a ItemId for S_LPROC32_ID, S_GPROC32_ID, S_LPROC32_DPC_ID, S_GPROC32EX_ID, S_LPROC32EX_ID.

offset_segment: OffsetSegmentflags: u8