ProcFlags

Struct ProcFlags 

pub struct ProcFlags(/* private fields */);
Flags describing a procedure symbol.

See: CV_PROCFLAGS in cvinfo.h.

Implementations

Source

impl ProcFlags

pub const NOFPO: ProcFlags

Frame pointer present.

pub const INT: ProcFlags

Interrupt return.

pub const FAR: ProcFlags

Far return.

pub const NEVER: ProcFlags

Does not return.

pub const NOTREACHED: ProcFlags

Label isn’t fallen into.

pub const CUST_CALL: ProcFlags

Custom calling convention.

pub const NOINLINE: ProcFlags

Marked as noinline.

pub const OPTDBGINFO: ProcFlags

Has debug information for optimized code.

Source

impl ProcFlags

pub const fn empty() -> ProcFlags

Get a flags value with all bits unset.

pub const fn all() -> ProcFlags

Get a flags value with all known bits set.

pub const fn bits(&self) -> u8

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u8) -> Option<ProcFlags>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u8) -> ProcFlags

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u8) -> ProcFlags

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<ProcFlags>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: ProcFlags) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: ProcFlags) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: ProcFlags)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: ProcFlags)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: ProcFlags)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: ProcFlags, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: ProcFlags) -> ProcFlags

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: ProcFlags) -> ProcFlags

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: ProcFlags) -> ProcFlags

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: ProcFlags) -> ProcFlags

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> ProcFlags

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl ProcFlags

pub const fn iter(&self) -> Iter<ProcFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<ProcFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.