pub struct SymKind(pub u16);Expand description
Identifies symbol records.
Symbol records are stored in the Global Symbol Stream and in each per-module symbol stream.
Many symbols can only appear in the Global Symbol Stream or in a per-module symbol stream.
Tuple Fields
0: u16Implementations
Sourceimpl SymKind
impl SymKind
pub const S_COMPILE: SymKind
pub const S_END: SymKind
pub const S_SKIP: SymKind
pub const S_CVRESERVE: SymKind
pub const S_OBJNAME_ST: SymKind
pub const S_RETURN: SymKind
pub const S_PROCREF_ST: SymKind
pub const S_DATAREF_ST: SymKind
pub const S_ALIGN: SymKind
pub const S_LPROCREF_ST: SymKind
pub const S_OEM: SymKind
pub const S_TI16_MAX: SymKind
pub const S_REGISTER_ST: SymKind
pub const S_CONSTANT_ST: SymKind
pub const S_UDT_ST: SymKind
pub const S_COBOLUDT_ST: SymKind
pub const S_MANYREG_ST: SymKind
pub const S_BPREL32_ST: SymKind
pub const S_LDATA32_ST: SymKind
pub const S_GDATA32_ST: SymKind
pub const S_PUB32_ST: SymKind
pub const S_LPROC32_ST: SymKind
pub const S_GPROC32_ST: SymKind
pub const S_VFTABLE32: SymKind
pub const S_REGREL32_ST: SymKind
pub const S_LTHREAD32_ST: SymKind
pub const S_GTHREAD32_ST: SymKind
pub const S_FRAMEPROC: SymKind
pub const S_ANNOTATION: SymKind
pub const S_OBJNAME: SymKind
pub const S_THUNK32: SymKind
pub const S_BLOCK32: SymKind
pub const S_WITH32: SymKind
pub const S_LABEL32: SymKind
pub const S_REGISTER: SymKind
pub const S_CONSTANT: SymKind
pub const S_UDT: SymKind
pub const S_COBOLUDT: SymKind
pub const S_MANYREG: SymKind
pub const S_BPREL32: SymKind
pub const S_LDATA32: SymKind
pub const S_GDATA32: SymKind
pub const S_PUB32: SymKind
pub const S_LPROC32: SymKind
pub const S_GPROC32: SymKind
pub const S_REGREL32: SymKind
pub const S_LTHREAD32: SymKind
pub const S_GTHREAD32: SymKind
pub const S_COMPILE2: SymKind
pub const S_MANYREG2: SymKind
pub const S_LPROCIA64: SymKind
pub const S_GPROCIA64: SymKind
pub const S_LOCALSLOT: SymKind
pub const S_PARAMSLOT: SymKind
pub const S_LMANDATA: SymKind
pub const S_GMANDATA: SymKind
pub const S_MANFRAMEREL: SymKind
pub const S_MANREGISTER: SymKind
pub const S_MANSLOT: SymKind
pub const S_MANMANYREG: SymKind
pub const S_MANREGREL: SymKind
pub const S_MANMANYREG2: SymKind
pub const S_UNAMESPACE: SymKind
pub const S_PROCREF: SymKind
pub const S_DATAREF: SymKind
pub const S_LPROCREF: SymKind
pub const S_ANNOTATIONREF: SymKind
pub const S_TOKENREF: SymKind
pub const S_GMANPROC: SymKind
pub const S_LMANPROC: SymKind
pub const S_TRAMPOLINE: SymKind
pub const S_MANCONSTANT: SymKind
pub const S_ATTR_FRAMEREL: SymKind
pub const S_ATTR_REGISTER: SymKind
pub const S_ATTR_REGREL: SymKind
pub const S_ATTR_MANYREG: SymKind
pub const S_SEPCODE: SymKind
pub const S_LOCAL_2005: SymKind
pub const S_DEFRANGE_2005: SymKind
pub const S_DEFRANGE2_2005: SymKind
pub const S_SECTION: SymKind
pub const S_COFFGROUP: SymKind
pub const S_EXPORT: SymKind
pub const S_CALLSITEINFO: SymKind
pub const S_FRAMECOOKIE: SymKind
pub const S_DISCARDED: SymKind
pub const S_COMPILE3: SymKind
pub const S_ENVBLOCK: SymKind
pub const S_LOCAL: SymKind
pub const S_DEFRANGE: SymKind
pub const S_DEFRANGE_SUBFIELD: SymKind
pub const S_DEFRANGE_REGISTER: SymKind
pub const S_DEFRANGE_FRAMEPOINTER_REL: SymKind
pub const S_DEFRANGE_SUBFIELD_REGISTER: SymKind
pub const S_DEFRANGE_FRAMEPOINTER_REL_FULL_SCOPE: SymKind
pub const S_DEFRANGE_REGISTER_REL: SymKind
pub const S_LPROC32_ID: SymKind
pub const S_GPROC32_ID: SymKind
pub const S_LPROCMIPS_ID: SymKind
pub const S_GPROCMIPS_ID: SymKind
pub const S_LPROCIA64_ID: SymKind
pub const S_GPROCIA64_ID: SymKind
pub const S_BUILDINFO: SymKind
pub const S_INLINESITE: SymKind
pub const S_INLINESITE_END: SymKind
pub const S_PROC_ID_END: SymKind
pub const S_DEFRANGE_HLSL: SymKind
pub const S_GDATA_HLSL: SymKind
pub const S_LDATA_HLSL: SymKind
pub const S_FILESTATIC: SymKind
pub const S_LOCAL_DPC_GROUPSHARED: SymKind
pub const S_LPROC32_DPC: SymKind
pub const S_LPROC32_DPC_ID: SymKind
pub const S_DEFRANGE_DPC_PTR_TAG: SymKind
pub const S_DPC_SYM_TAG_MAP: SymKind
pub const S_ARMSWITCHTABLE: SymKind
pub const S_CALLEES: SymKind
pub const S_CALLERS: SymKind
pub const S_POGODATA: SymKind
pub const S_INLINESITE2: SymKind
pub const S_HEAPALLOCSITE: SymKind
pub const S_MOD_TYPEREF: SymKind
pub const S_REF_MINIPDB: SymKind
pub const S_PDBMAP: SymKind
pub const S_GDATA_HLSL32: SymKind
pub const S_LDATA_HLSL32: SymKind
pub const S_GDATA_HLSL32_EX: SymKind
pub const S_LDATA_HLSL32_EX: SymKind
pub const S_FASTLINK: SymKind
pub const S_INLINEES: SymKind
pub const S_HOTPATCHFUNC: SymKind
Sourceimpl SymKind
impl SymKind
Sourcepub fn starts_scope(self) -> bool
pub fn starts_scope(self) -> bool
True if this SymKind starts a scope. All symbols that start a block begin with
[BlockHeader].
Sourcepub fn ends_scope(self) -> bool
pub fn ends_scope(self) -> bool
Indicates whether this SymKind ends a scope.
There are no SymKind values that both start and end a scope.
In all well-formed symbol streams, every symbol that starts a scope has a matching symbol that ends that scope.
Sourcepub fn is_refsym_target(self) -> bool
pub fn is_refsym_target(self) -> bool
Returns true if this symbol can be the target of a “reference to symbol” in the
Global Symbol Stream.
Sourcepub fn is_refsym_source(self) -> bool
pub fn is_refsym_source(self) -> bool
Returns true if this symbol can be the source of a “reference to symbol”
in the Global Symbol Stream.