pub struct TypeIndexMap {
pub type_index_begin: TypeIndex,
pub type_index_end: TypeIndex,
pub starts: Vec<u32>,
}Expand description
Maps TypeIndex values to the byte range of records within a type stream.
Fields
type_index_begin: TypeIndexCopied from type stream header.
type_index_end: TypeIndexCopied from type stream header.
starts: Vec<u32>Contains a “starts” vector for the byte offsets of each type record.
This vector has an additional value at the end, which gives the size in bytes of the type stream.
Implementations
Sourceimpl TypeIndexMap
impl TypeIndexMap
Sourcepub fn is_primitive(&self, ti: TypeIndex) -> bool
pub fn is_primitive(&self, ti: TypeIndex) -> bool
Tests whether a TypeIndex is a primitive type.
Sourcepub fn record_range(&self, ti: TypeIndex) -> Result<Range<usize>>
pub fn record_range(&self, ti: TypeIndex) -> Result<Range<usize>>
Given a TypeIndex, returns the byte range within a TypeStream where that record
is stored.
If ti is a primitive type then this function will return Err. The caller should
use the is_primitive method to check whether a TypeIndex is a primitive type.