Struct TypeStreamHeader

#[repr(C)]
pub struct TypeStreamHeader {
Show 15 fields pub version: U32<LE>, pub header_size: U32<LE>, pub type_index_begin: TypeIndexLe, pub type_index_end: TypeIndexLe, pub type_record_bytes: U32<LE>, pub hash_stream_index: StreamIndexU16, pub hash_aux_stream_index: StreamIndexU16, pub hash_key_size: U32<LE>, pub num_hash_buckets: U32<LE>, pub hash_value_buffer_offset: I32<LE>, pub hash_value_buffer_length: U32<LE>, pub index_offset_buffer_offset: I32<LE>, pub index_offset_buffer_length: U32<LE>, pub hash_adj_buffer_offset: I32<LE>, pub hash_adj_buffer_length: U32<LE>,
}
The header of the TPI stream.

Fields

version: U32<LE>header_size: U32<LE>type_index_begin: TypeIndexLetype_index_end: TypeIndexLetype_record_bytes: U32<LE>

The number of bytes of type record data following the TypeStreamHeader.

hash_stream_index: StreamIndexU16hash_aux_stream_index: StreamIndexU16hash_key_size: U32<LE>

The size of each hash key in the Hash Value Substream. For the current version of TPI, this value should always be 4.

num_hash_buckets: U32<LE>

The number of hash buckets. This is used when calculating the record hashes. Each hash is computed, and then it is divided by num_hash_buckets and the remainder becomes the final hash.

If hash_value_buffer_length is non-zero, then num_hash_buckets must also be non-zero.

hash_value_buffer_offset: I32<LE>hash_value_buffer_length: U32<LE>index_offset_buffer_offset: I32<LE>index_offset_buffer_length: U32<LE>hash_adj_buffer_offset: I32<LE>hash_adj_buffer_length: U32<LE>

Implementations

Source

impl TypeStreamHeader

pub fn empty() -> Self

Makes an empty one