Struct TypeIndex

pub struct TypeIndex(pub u32);
A type index refers to another type record, or to a primitive type.

Tuple Fields

0: u32

Implementations

Source

impl TypeIndex

pub const T_NOTYPE: TypeIndex

Primitive type: none

pub const T_VOID: TypeIndex

Primitive type: void

pub const T_HRESULT: TypeIndex

Primitive type: HRESULT

pub const T_NOTTRANS: TypeIndex

Primitive type: <type-not-translated>

pub const T_CHAR: TypeIndex

Primitive type: char

pub const T_SHORT: TypeIndex

Primitive type: short

pub const T_LONG: TypeIndex

Primitive type: long

pub const T_QUAD: TypeIndex

Primitive type: long long

pub const T_OCT: TypeIndex

Primitive type: __int128

pub const T_UCHAR: TypeIndex

Primitive type: unsigned char

pub const T_USHORT: TypeIndex

Primitive type: unsigned short

pub const T_ULONG: TypeIndex

Primitive type: unsigned long

pub const T_UQUAD: TypeIndex

Primitive type: unsigned long long

pub const T_UOCT: TypeIndex

Primitive type: unsigned __int128

pub const T_BOOL8: TypeIndex

Primitive type: bool

pub const T_BOOL16: TypeIndex

Primitive type: bool16

pub const T_BOOL32: TypeIndex

Primitive type: bool32

pub const T_BOOL64: TypeIndex

Primitive type: bool64

pub const T_REAL32: TypeIndex

Primitive type: float

pub const T_REAL64: TypeIndex

Primitive type: double

pub const T_INT1: TypeIndex

Primitive type: __int8

pub const T_UINT1: TypeIndex

Primitive type: unsigned __int8

pub const T_RCHAR: TypeIndex

Primitive type: char

pub const T_WCHAR: TypeIndex

Primitive type: wchar_t

pub const T_INT2: TypeIndex

Primitive type: __int16

pub const T_UINT2: TypeIndex

Primitive type: unsigned __int16

pub const T_INT4: TypeIndex

Primitive type: __int32

pub const T_UINT4: TypeIndex

Primitive type: unsigned __int32

pub const T_INT8: TypeIndex

Primitive type: __int64

pub const T_UINT8: TypeIndex

Primitive type: unsigned __int64

pub const T_CHAR16: TypeIndex

Primitive type: char16

pub const T_CHAR32: TypeIndex

Primitive type: char32

pub const T_32PVOID: TypeIndex

Primitive type: void *

pub const T_32PHRESULT: TypeIndex

Primitive type: HRESULT *

pub const T_32PCHAR: TypeIndex

Primitive type: char *

pub const T_32PSHORT: TypeIndex

Primitive type: short *

pub const T_32PLONG: TypeIndex

Primitive type: long *

pub const T_32PQUAD: TypeIndex

Primitive type: long long *

pub const T_32POCT: TypeIndex

Primitive type: __int128 *

pub const T_32PUCHAR: TypeIndex

Primitive type: unsigned char *

pub const T_32PUSHORT: TypeIndex

Primitive type: unsigned short *

pub const T_32PULONG: TypeIndex

Primitive type: unsigned __int32 *

pub const T_32PUQUAD: TypeIndex

Primitive type: long long *

pub const T_32PUOCT: TypeIndex

Primitive type: unsigned __int128 *

pub const T_32PBOOL08: TypeIndex

Primitive type: bool *

pub const T_32PBOOL16: TypeIndex

Primitive type: bool16 *

pub const T_32PBOOL32: TypeIndex

Primitive type: bool32 *

pub const T_32PBOOL64: TypeIndex

Primitive type: bool64 *

pub const T_32PREAL32: TypeIndex

Primitive type: float *

pub const T_32PREAL64: TypeIndex

Primitive type: double *

pub const T_32PUINT1: TypeIndex

Primitive type: unsigned __int8 *

pub const T_32PINT1: TypeIndex

Primitive type: __int8 *

pub const T_32PRCHAR: TypeIndex

Primitive type: char *

pub const T_32PWCHAR: TypeIndex

Primitive type: wchar_t *

pub const T_32PINT2: TypeIndex

Primitive type: __int16 *

pub const T_32PUINT2: TypeIndex

Primitive type: unsigned __int16 *

pub const T_32PINT4: TypeIndex

Primitive type: __int32 *

pub const T_32PUINT4: TypeIndex

Primitive type: unsigned __int32 *

pub const T_32PINT8: TypeIndex

Primitive type: __int64 *

pub const T_32PUINT8: TypeIndex

Primitive type: unsigned __int64 *

pub const T_32PCHAR16: TypeIndex

Primitive type: char16 *

pub const T_32PCHAR32: TypeIndex

Primitive type: char32 *

pub const T_64PVOID: TypeIndex

Primitive type: void *

pub const T_64PHRESULT: TypeIndex

Primitive type: HRESULT *

pub const T_64PCHAR: TypeIndex

Primitive type: char *

pub const T_64PSHORT: TypeIndex

Primitive type: short *

pub const T_64PLONG: TypeIndex

Primitive type: long *

pub const T_64PQUAD: TypeIndex

Primitive type: long long *

pub const T_64POCT: TypeIndex

Primitive type: __int128 *

pub const T_64PPUCHAR: TypeIndex

Primitive type: unsigned char *

pub const T_64PUSHORT: TypeIndex

Primitive type: unsigned short *

pub const T_64PULONG: TypeIndex

Primitive type: unsigned __int32 *

pub const T_64PUQUAD: TypeIndex

Primitive type: long long *

pub const T_64PUOCT: TypeIndex

Primitive type: unsigned __int128 *

pub const T_64PBOOL08: TypeIndex

Primitive type: bool *

pub const T_64PBOOL16: TypeIndex

Primitive type: bool16 *

pub const T_64PBOOL32: TypeIndex

Primitive type: bool32 *

pub const T_64PBOOL64: TypeIndex

Primitive type: bool64 *

pub const T_64PREAL32: TypeIndex

Primitive type: float *

pub const T_64PREAL64: TypeIndex

Primitive type: double *

pub const T_64PUINT1: TypeIndex

Primitive type: unsigned __int8 *

pub const T_64PINT1: TypeIndex

Primitive type: __int8 *

pub const T_64PRCHAR: TypeIndex

Primitive type: char *

pub const T_64PWCHAR: TypeIndex

Primitive type: wchar_t *

pub const T_64PINT2: TypeIndex

Primitive type: __int16 *

pub const T_64PUINT2: TypeIndex

Primitive type: unsigned __int16 *

pub const T_64PINT4: TypeIndex

Primitive type: __int32 *

pub const T_64PUINT4: TypeIndex

Primitive type: unsigned __int32 *

pub const T_64PINT8: TypeIndex

Primitive type: __int64 *

pub const T_64PUINT8: TypeIndex

Primitive type: unsigned __int64 *

pub const T_64PCHAR16: TypeIndex

Primitive type: char16 *

pub const T_64PCHAR32: TypeIndex

Primitive type: char32 *

Source

impl TypeIndex

pub const MIN_BEGIN: TypeIndex

The minimum value for a type_index_begin value.

This value comes from the fact that the first 0x1000 values are reserved for primitive types. See primitive_types.md in the specification.