Module align

Module align 

Alignment and padding utilities

Functions

alignment_bytes_needed_4
Returns the number of alignment padding bytes that are needed to reach an alignment of 4, given the number of bytes already in a buffer.