Function alignment_bytes_needed_4

pub fn alignment_bytes_needed_4(n: usize) -> usize
Returns the number of alignment padding bytes that are needed to reach an alignment of 4, given the number of bytes already in a buffer.