Module iter

Module iter 

Iterator utilities

Functions

group_by
Reads a slice of items and groups them using a function over the items.
group_by_iter
Reads a sequence of items and groups them using a function over the items.
group_by_iter_ref
Reads a sequence of items and groups them using a function over the items.