replace_range_copy

Function replace_range_copy 

pub fn replace_range_copy<T: Copy>(
    v: &mut Vec<T>,
    start: usize,
    old_len: usize,
    values: &[T],
)
Replace a range of values in a vector with a new range. The old and new ranges can be different sizes.