ModuleInfoFixed

Struct ModuleInfoFixed 

#[repr(C)]
pub struct ModuleInfoFixed { pub unused1: U32<LE>, pub section_contrib: SectionContribEntry, pub flags: U16<LE>, pub stream: StreamIndexU16, pub sym_byte_size: U32<LE>, pub c11_byte_size: U32<LE>, pub c13_byte_size: U32<LE>, pub source_file_count: U16<LE>, pub padding: [u8; 2], pub unused2: U32<LE>, pub source_file_name_index: U32<LE>, pub pdb_file_path_name_index: U32<LE>, }
The header of a Module Info record. Module Info records are stored in the DBI stream.

See dbi.h, MODI_60_Persist

Fields

unused1: U32<LE>

This appears to be a module index field, but it is not always set.

In some PDBs, we see this field being set to the zero-based index of this Module Info record in the DBI Modules Substream. In other PDBs, this value is 0. Set this to 0.

section_contrib: SectionContribEntry

This module’s first section contribution.

flags: U16<LE>

Various flags

  • bit 0: set to 1 if this module has been written since DBI opened
  • bit 1: set to 1 if this module has EC symbolic information
  • bits 2-7: not used
  • bits 8-15: index into TSM list for this mods server
stream: StreamIndexU16

Stream index of the Module Stream for this module, which contains the symbols and line data for this module. If this is 0xffff, then this module does not have a module info stream.

sym_byte_size: U32<LE>

Specifies the size of the symbols substream within the Module Stream.

c11_byte_size: U32<LE>

Specifies the length of the C11 Line Data in a Module Information Stream. C11 line data is obsolete and is not supported.

c13_byte_size: U32<LE>

Specifies the length of the C13 Line Data in a Module Information Stream.

source_file_count: U16<LE>

Number of files contributing to this module.

padding: [u8; 2]

Alignment padding.

unused2: U32<LE>

Do not read. Set to 0 when encoding.

source_file_name_index: U32<LE>

Unknown; possible that this relates to Edit-and-Continue.

pdb_file_path_name_index: U32<LE>

Unknown; possible that this relates to Edit-and-Continue.

Implementations

Source

impl ModuleInfoFixed

pub fn stream(&self) -> Option<u32>

Gets the stream for this module, if any. This stream contains the symbol data and C13 Line Data for the module.