pub struct DbiSourcesSubstream<'a> { /* private fields */ }Expand description
The “Sources” substream of the DBI stream. This stream describes the merged set of source files that were the inputs (compilands) of all modules.
See: https://llvm.org/docs/PDB/DbiStream.html#file-info-substream
Implementations
Sourceimpl<'a> DbiSourcesSubstream<'a>
impl<'a> DbiSourcesSubstream<'a>
Sourcepub fn num_modules(&self) -> usize
pub fn num_modules(&self) -> usize
The number of modules
Sourcepub fn file_name_offsets(&self) -> &'a [U32<LE>]
pub fn file_name_offsets(&self) -> &'a [U32<LE>]
Provides access to the file name offsets slice. Each value is a file name offset, and can
be used with get_source_name_at().
Sourcepub fn parse(substream_data: &'a [u8]) -> Result<Self>
pub fn parse(substream_data: &'a [u8]) -> Result<Self>
Parses the file info substream.
This does not parse or validate every part of the substream. It only parses enough to find the module indices and file names.
Sourcepub fn get_source_file_name(
&self,
source_file_index: usize,
) -> Result<&'a BStr, ParserError>
pub fn get_source_file_name( &self, source_file_index: usize, ) -> Result<&'a BStr, ParserError>
Given a source file index, returns the source file name.
Sourcepub fn get_source_file_name_at(
&self,
file_name_offset: u32,
) -> Result<&'a BStr, ParserError>
pub fn get_source_file_name_at( &self, file_name_offset: u32, ) -> Result<&'a BStr, ParserError>
Given a file name offset (within name_buffer), returns the source file name.
Sourcepub fn name_offsets_for_module(&self, module_index: usize) -> Result<&[U32<LE>]>
pub fn name_offsets_for_module(&self, module_index: usize) -> Result<&[U32<LE>]>
Caller is expected to validate module_index (against num_modules()) before calling
Sourcepub fn iter_sources(&self) -> IterSources<'_> ⓘ
pub fn iter_sources(&self) -> IterSources<'_> ⓘ
Iterates source files in the DBI Sources Substream.