MSVC hash algorithms
Functions
- hash_
mod_ u16 - Computes a 16-bit hash
- hash_
mod_ u32 - Computes a 32-bit hash. This produces the same results as the hash function used in the MSVC PDB reader library.
- hash_
sig - Computes a hash code using an algorithm equivalent to the
SigForPbCbfunction. This is a CRC-32 checksum with an initial value ofsig. - hash_
sig_ mod - Computes a CRC-32 with an initializer value, then computes the modulus of it.
- hash_
u32 - Computes a 32-bit hash, but does not compute a remainder (modulus).