Decodes line information found in Module Streams.
References
Structs
- Block
- One block of line data. Each block has a header which points to a source file. All of the line locations within the block point to line numbers (and potentially column numbers) within that source file.
- Block
Header - Header for a variable-length Block record.
- Block
Mut - One block of line data. Each block has a header which points to a source file. All of the line locations within the block point to line numbers (and potentially column numbers) within that source file.
- Checksum
Kind - The hash algorithm used for the checksum.
- Column
Record - A single column record
- Contribution
- File
Checksum - Points to a single file checksum record.
- File
Checksum Header - The header at the start of a file checksum record.
- File
Checksum Iter - Iterates FileChecksum values from a byte stream.
- File
Checksum Mut - Points to a single file checksum record, with mutable access.
- File
Checksum MutIter - Iterator state. Iterates
FileChecksumMutvalues. - File
Checksums Subsection - The File Checksums Subection
- File
Checksums Subsection Mut - Like
FileChecksums, but with mutable access - Iter
Blocks - Iterator state for
LinesSubsection::blocks. - Iter
Blocks Mut - Iterator state for
LinesSubsection::blocks. - Line
Data - Enables decoding of the line data stored in a Module Stream. This decodes the “C13 line data” substream.
- Line
Data Mut - Enables decoding of the line data stored in a Module Stream. This decodes the “C13 line data” substream.
- Line
Record - A single line record
- Lines
Entry - Lines
Subsection - Represents one contribution. Each contribution consists of a sequence of variable-length blocks.
- Lines
Subsection Mut - Represents one contribution. Each contribution consists of a sequence of variable-length blocks.
- Subsection
- A reference to one subsection
- Subsection
Header - The header of a subsection.
- Subsection
Iter - Iterator state for subsections
- Subsection
Iter Mut - Iterator state for subsections with mutable access
- Subsection
Kind - Enumerates the kind of subsections found in C13 Line Data.
- Subsection
Mut - A reference to one subsection, with mutable access
Constants
- CV_
LINES_ HAVE_ COLUMNS - Bit flag for
Contribution::flagsfield - JMC_
LINE_ FEE_ FEE - This special line number is part of the “Just My Code” MSVC compiler feature.
- JMC_
LINE_ NO_ STEP_ INTO - This special line number is part of the “Just My Code” MSVC compiler feature.
Functions
- fixup_
c13_ line_ data - Updates a C13 Line Data substream after NameIndex values have been updated and after file lists for a given module have been rearranged (sorted).
- is_
jmc_ line - Returns true if
lineis a number that is used by the “Just My Code” MSVC compiler feature.