Struct BlockHeader

#[repr(C)]
pub struct BlockHeader { pub file_index: U32<LE>, pub num_lines: U32<LE>, pub block_size: U32<LE>, }
Header for a variable-length Block record.

Each block contains a sequence of line records, and optionally column records.

Fields

file_index: U32<LE>

The byte offset into the file checksums subsection for this file.

num_lines: U32<LE>

The number of LineRecord entries that immediately follow this structure. Also, if the contribution header indicates that the contribution has column values, this specifies the number of column records that follow the file records.

block_size: U32<LE>

Size of the data for this block. This value includes the size of the block header itself, so the minimum value value is 12.