pub struct NamesStream<StreamData>{
pub stream_data: StreamData,
pub strings_size: usize,
pub num_hashes: usize,
pub hashes_offset: usize,
pub num_strings: usize,
}Expand description
Reads the /names stream.
Fields
stream_data: StreamDataContains the stream data of the /names stream.
strings_size: usizeThe size of the string data. This value comes from the stream header.
num_hashes: usizeThe number of entries in the hash table.
hashes_offset: usizeThe byte offset within stream_data where the hash records begin. Each hash record
contains a NameIndex value. The number of elements is num_hashes.
num_strings: usizeThe is the number of strings from the stream trailer. Nothing guarantees that this value correctly reflects the number of strings in the string data.
Implementations
Sourceimpl<StreamData> NamesStream<StreamData>
impl<StreamData> NamesStream<StreamData>
Sourcepub fn parse(stream_data: StreamData) -> Result<Self>
pub fn parse(stream_data: StreamData) -> Result<Self>
Parses and validates the stream header.
This function does not validate all of the strings in the table.
The check() function performs extensive checks.
Sourcepub fn strings_range(&self) -> Range<usize>
pub fn strings_range(&self) -> Range<usize>
Returns the byte range within the stream of the string data.
Sourcepub fn strings_bytes(&self) -> &[u8] ⓘ
pub fn strings_bytes(&self) -> &[u8] ⓘ
Gets the strings data
Sourcepub fn hashes(&self) -> &[U32<LE>]
pub fn hashes(&self) -> &[U32<LE>]
Gets the hash table. Each entry contains NameIndex, or 0. The entries are arranged in the order of the hash of the strings.
Sourcepub fn get_string(&self, offset: NameIndex) -> Result<&BStr>
pub fn get_string(&self, offset: NameIndex) -> Result<&BStr>
Retrieves one string from the string table.
Sourcepub fn iter(&self) -> IterNames<'_> ⓘ
pub fn iter(&self) -> IterNames<'_> ⓘ
Iterates the strings in the table, by reading the character data directly.
By convention, the string table usually begins with the empty string. However, this is not a guarantee of this implementation.
This iterator may iterate empty strings at the end of the sequence, due to alignment bytes at the end of the string data.
Sourcepub fn rebuild(&self) -> (NameIndexMapping, Vec<u8>)
pub fn rebuild(&self) -> (NameIndexMapping, Vec<u8>)
Sorts the Names Stream and removes duplicates. This also eliminates duplicate strings.
Returns (remapping_table, new_stream_data). The remapping_table contains tuples of
(old_offset, new_offset) and is sorted by old_offset. The caller can use a binary
search to remap entries.
Sourceimpl NamesStream<Vec<u8>>
impl NamesStream<Vec<u8>>
Sourcepub fn load_and_parse<F: ReadAt>(
pdb: &Msf<F>,
named_streams: &NamedStreams,
) -> Result<Self>
pub fn load_and_parse<F: ReadAt>( pdb: &Msf<F>, named_streams: &NamedStreams, ) -> Result<Self>
Reads the Names Stream and parses its header.