Struct RandomAccessFile

pub struct RandomAccessFile(/* private fields */);
A file with cross-platform positioned I/O.

Reading from this file or writing to it does not use its internal OS cursor, but it may move it anyway. This can cause surprising behaviour if shared with a File (this could be done with try_clone).

Implementations

Source

impl RandomAccessFile

pub fn open<P>(path: P) -> Result<RandomAccessFile, Error>
where P: AsRef<Path>,

Attempts to open a file in read-only mode.

See File::open for details.

pub fn create<P>(path: P) -> Result<RandomAccessFile, Error>
where P: AsRef<Path>,

Opens a file in write-only mode.

See File::create for details.

pub fn sync_all(&self) -> Result<(), Error>

Attempts to sync all OS-internal metadata to disk.

See File::sync_all for details.

pub fn sync_data(&self) -> Result<(), Error>

This function is similar to sync_all, except that it may not synchronize file metadata to the filesystem.

See File::sync_data for details.

pub fn set_len(&self, size: u64) -> Result<(), Error>

Truncates or extends the underlying file, updating the size of this file to become size.

See File::set_len for details.

pub fn metadata(&self) -> Result<Metadata, Error>

Queries metadata about the underlying file.

See File::metadata for details.

pub fn try_clone(&self) -> Result<RandomAccessFile, Error>

Creates a new File instance that shares the same underlying file handle as the existing File instance

See File::try_clone for details.

pub fn set_permissions(&self, perm: Permissions) -> Result<(), Error>

Changes the permissions on the underlying file.

See File::set_permissions for details.

pub fn into_inner(self) -> File

Unwraps the inner File.

The file’s cursor position is unspecified.