Determines whether a given file header is a PDB/MSF file, PDBZ/MSFZ file, or a Portable PDB file.
Enums
- Flavor
- Enumerates the kind of PDBs files that are recognized.
Functions
- what_
flavor - Determines whether a given file header is a PDB/MSF file, PDBZ/MSFZ file, or a Portable PDB file.