pub struct TypeStream<StreamData>{
pub stream_data: StreamData,
/* private fields */
}Expand description
Contains a TPI Stream or IPI Stream.
Fields
stream_data: StreamDataThe stream data. This contains the entire type stream, including header and type records.
Implementations
Sourceimpl<StreamData> TypeStream<StreamData>
impl<StreamData> TypeStream<StreamData>
Sourcepub fn header(&self) -> Option<&TypeStreamHeader>
pub fn header(&self) -> Option<&TypeStreamHeader>
Gets a reference to the stream header
Sourcepub fn version(&self) -> u32
pub fn version(&self) -> u32
Returns the version of the stream, or TYPE_STREAM_VERSION_2004 if this is an empty stream.
Sourcepub fn hash_stream(&self) -> Option<u32>
pub fn hash_stream(&self) -> Option<u32>
Returns the stream index of the related hash stream, if any.
Sourcepub fn header_mut(&mut self) -> Option<&mut TypeStreamHeader>
pub fn header_mut(&mut self) -> Option<&mut TypeStreamHeader>
Gets a mutable reference to the stream header
Sourcepub fn type_index_begin(&self) -> TypeIndex
pub fn type_index_begin(&self) -> TypeIndex
The type index of the first type record.
Sourcepub fn type_index_end(&self) -> TypeIndex
pub fn type_index_end(&self) -> TypeIndex
The type index of the last type record, plus 1.
Sourcepub fn records_offset(&self) -> usize
pub fn records_offset(&self) -> usize
Gets the byte offset within the stream of the record data.
Sourcepub fn type_records_bytes(&self) -> &[u8] ⓘ
pub fn type_records_bytes(&self) -> &[u8] ⓘ
Returns the encoded type records found in the TPI or IPI stream.
The type records immediately follow the type stream. The length is given by the header field type_record_bytes. The values in the header were validated in read_tpi_or_ipi_stream(), so we do not need to check them again, here.
Sourcepub fn type_records_bytes_mut(&mut self) -> &mut [u8] ⓘ
pub fn type_records_bytes_mut(&mut self) -> &mut [u8] ⓘ
Returns the encoded type records found in the type stream.
Sourcepub fn type_records_range(&self) -> Range<usize>
pub fn type_records_range(&self) -> Range<usize>
Returns the byte range of the encoded type records found in the type stream.
Sourcepub fn iter_type_records(&self) -> TypesIter<'_> ⓘ
pub fn iter_type_records(&self) -> TypesIter<'_> ⓘ
Iterates the types contained within this type stream.
Sourcepub fn parse(stream_index: Stream, stream_data: StreamData) -> Result<Self>
pub fn parse(stream_index: Stream, stream_data: StreamData) -> Result<Self>
Parses the header of a Type Stream and validates it.
Sourcepub fn build_types_starts(&self) -> TypeIndexMap
pub fn build_types_starts(&self) -> TypeIndexMap
Builds a “starts” table that gives the starting location of each type record.
Sourcepub fn to_ref(&self) -> TypeStream<&[u8]>
pub fn to_ref(&self) -> TypeStream<&[u8]>
Creates a new TypeStream that referenced the stream data of this TypeStream.
This is typically used for temporarily creating a TypeStream<&[u8]> from a
TypeStream<Vec<u8>>.
Sourcepub fn record_starts(&self) -> &[u32]
pub fn record_starts(&self) -> &[u32]
Gets the “starts” vector for the byte offsets of the records in this TypeStream.
This function will create the starts vector on-demand.
Sourcepub fn is_primitive(&self, type_index: TypeIndex) -> bool
pub fn is_primitive(&self, type_index: TypeIndex) -> bool
Returns true if type_index refers to a primitive type.
Sourcepub fn record(&self, type_index: TypeIndex) -> Result<TypeRecord<'_>>
pub fn record(&self, type_index: TypeIndex) -> Result<TypeRecord<'_>>
Retrieves the type record identified by type_index.
This should only be used for non-primitive TypeIndex values. If this is called with a
primitive TypeIndex then it will return Err.
Sourcepub fn iter_fields(
&self,
field_list: TypeIndex,
) -> IterFieldChain<'_, StreamData> ⓘ
pub fn iter_fields( &self, field_list: TypeIndex, ) -> IterFieldChain<'_, StreamData> ⓘ
Iterate the fields of an LF_STRUCTURE, LF_CLASS, LF_ENUM, etc. This correctly
iterates across chains of LF_FIELDLIST.