Misc utilities
Modules
- align
- Alignment and padding utilities
- io
- iter
- Iterator utilities
- path
- Utilities for working with filesystem paths
- swizzle
- Traits and support for in-place byte-order swizzling
- vec
- Utilities for
Vec
Structs
- Iter
Similar Ranges - Iterates ranges of items within a slice that share a common property.
- Iter
Similar Slices - Iterates slices of items within a slice that share a common property.
- Iter
Similar Slices Mut - Iterates slices of items within a slice that share a common property.
- Starts
Of - Helps decode records that are indexed using “starts” arrays.
Functions
- align_4
- Align n up to the next multiple of 4, if it is not already a multiple of 4.
- copy_
from_ bytes - Copies a value that implements
FromBytes, by simply copying its byte representation. - is_
aligned_ 4 - True if
nis a multiple of 4. - iter_
similar_ ranges - Iterates ranges of items within a slice that share a common property.
- iter_
similar_ slices - Iterates ranges of items within a slice that share a common property.
- iter_
similar_ slices_ mut - Iterates ranges of items within a slice that share a common property.