Module utils

Misc utilities

Modules

align
Alignment and padding utilities
io
iter
Iterator utilities
path
Utilities for working with filesystem paths
swizzle
Traits and support for in-place byte-order swizzling
vec
Utilities for Vec

Structs

IterSimilarRanges
Iterates ranges of items within a slice that share a common property.
IterSimilarSlices
Iterates slices of items within a slice that share a common property.
IterSimilarSlicesMut
Iterates slices of items within a slice that share a common property.
StartsOf
Helps decode records that are indexed using “starts” arrays.

Functions

align_4
Align n up to the next multiple of 4, if it is not already a multiple of 4.
copy_from_bytes
Copies a value that implements FromBytes, by simply copying its byte representation.
is_aligned_4
True if n is a multiple of 4.
iter_similar_ranges
Iterates ranges of items within a slice that share a common property.
iter_similar_slices
Iterates ranges of items within a slice that share a common property.
iter_similar_slices_mut
Iterates ranges of items within a slice that share a common property.