Alignment and padding utilities
Functions
- alignment_
bytes_ needed_ 4 - Returns the number of alignment padding bytes that are needed to reach an alignment of 4, given the number of bytes already in a buffer.
Alignment and padding utilities