Iterator utilities
Functions
- group_
by - Reads a slice of items and groups them using a function over the items.
- group_
by_ iter - Reads a sequence of items and groups them using a function over the items.
- group_
by_ iter_ ref - Reads a sequence of items and groups them using a function over the items.